Modules
Enums
Traits
- Trait for self intersection tests where the end points are excluded
- Trait for self intersection tests where the end points are included
Functions
- Get any intersection point between line segments. Note that this function always detects endpoint-to-endpoint intersections. Most of this is from https://stackoverflow.com/a/565282
- Get any intersection point between line segment and point. Inspired by https://stackoverflow.com/a/17590923
- Utility function converting an array slice into a vec of Line
- ulps_eq
Deprecated - returns true if the two coordinates are virtually identical